@@ -5,13 +5,10 @@
 
 from __future__ import annotations
 
-from contextlib import contextmanager
-from io import BytesIO
 from pathlib import Path
 from subprocess import PIPE
 
 from packaging.version import Version
-from PIL import Image
 
 from ocrmypdf.exceptions import MissingDependencyError
 from ocrmypdf.subprocess import get_version, run
@@ -29,21 +26,16 @@ def available():
     return True
 
 
-@contextmanager
-def input_as_png(input_file: Path):
-    if not input_file.name.endswith('.png'):
-        with Image.open(input_file) as im:
-            bio = BytesIO()
-            im.save(bio, format='png')
-            bio.seek(0)
-            yield bio
-    else:
-        with open(input_file, 'rb') as f:
-            yield f
-
-
 def quantize(input_file: Path, output_file: Path, quality_min: int, quality_max: int):
-    with input_as_png(input_file) as input_stream:
+    """Quantize a PNG image using pngquant.
+
+    Args:
+        input_file: Input PNG image
+        output_file: Output PNG image
+        quality_min: Minimum quality to use
+        quality_max: Maximum quality to use
+    """
+    with open(input_file, 'rb') as input_stream:
         args = [
             'pngquant',
             '--force',
@@ -58,7 +50,3 @@ def quantize(input_file: Path, output_file: Path, quality_min: int, quality_max:
     if result.returncode == 0:
         # input_file could be the same as output_file, so we defer the write
         output_file.write_bytes(result.stdout)
-
-
-def quantize_mp(args):
-    return quantize(*args)
