@@ -270,7 +270,7 @@ def check_pdf(input_file: Path) -> bool:
         with pdf:
             with warnings.catch_warnings():
                 warnings.filterwarnings('ignore', message=r'pikepdf.*JBIG2.*')
-                messages = pdf.check()
+                messages = pdf.check_pdf_syntax()
             success = True
             for msg in messages:
                 if 'error' in msg.lower():
