@@ -4,6 +4,7 @@
 from __future__ import annotations
 
 import pickle
+import warnings
 from io import BytesIO
 from math import isclose
 
@@ -20,6 +21,10 @@ from ocrmypdf.helpers import IMG2PDF_KWARGS, Resolution
 from ocrmypdf.pdfinfo import Colorspace, Encoding
 from ocrmypdf.pdfinfo.layout import PDFPage
 
+warnings.filterwarnings(
+    "ignore", category=DeprecationWarning, module="reportlab.lib.rl_safe_eval"
+)
+
 # pylint: disable=protected-access
 
 
@@ -203,12 +208,13 @@ def test_pages_issue700(monkeypatch, resources):
     monkeypatch.setattr(PDFPage, 'get_pages', get_no_pages)
 
     with pytest.raises(InputFileError, match="pdfminer"):
-        pdfinfo.PdfInfo(
+        pi = pdfinfo.PdfInfo(
             resources / 'cardinal.pdf',
             detailed_analysis=True,
             progbar=False,
             max_workers=1,
         )
+        pi._miner_state.get_page_analysis(0)
 
 
 @pytest.fixture
